@@ -1,6 +1,6 @@
 __title__ = 'starbase'
-__version__ = '0.3.2'
-__build__ = 0x00000c
+__version__ = '0.3.3'
+__build__ = 0x00000d
 __author__ = 'Artur Barseghyan'
 __copyright__ = 'Copyright (c) 2013-2014 Artur Barseghyan'
 __license__ = 'GPL 2.0/LGPL 2.1'
